[SCM] WebKit Debian packaging branch, webkit-1.2, updated. upstream/1.1.90-6072-g9a69373

eric at webkit.org eric at webkit.org
Thu Apr 8 00:24:08 UTC 2010


The following commit has been merged in the webkit-1.2 branch:
commit 6e98fcfb6dff4330cf49e9b0fd227f8915c6be5d
Author: eric at webkit.org <eric at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Mon Dec 7 20:17:20 2009 +0000

    2009-12-07  Yaar Schnitman  <yaar at chromium.org>
    
            Reviewed by Darin Fisher.
    
            fixes to build-webkit --chromium
            https://bugs.webkit.org/show_bug.cgi?id=32179
    
            * DEPS:
            * WebKit.gyp:
            * gyp_webkit:
    2009-12-07  Yaar Schnitman  <yaar at chromium.org>
    
            Reviewed by Darin Fisher.
    
            fixes to build-webkit --chromium
            https://bugs.webkit.org/show_bug.cgi?id=32179
    
            * Scripts/webkitdirs.pm:
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@51788 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/chromium/ChangeLog b/WebKit/chromium/ChangeLog
index 5797d3e..c17a175 100644
--- a/WebKit/chromium/ChangeLog
+++ b/WebKit/chromium/ChangeLog
@@ -1,3 +1,14 @@
+2009-12-07  Yaar Schnitman  <yaar at chromium.org>
+
+        Reviewed by Darin Fisher.
+
+        fixes to build-webkit --chromium
+        https://bugs.webkit.org/show_bug.cgi?id=32179
+
+        * DEPS:
+        * WebKit.gyp:
+        * gyp_webkit:
+
 2009-12-07  Mikhail Naganov  <mnaganov at chromium.org>
 
         Reviewed by Pavel Feldman.
diff --git a/WebKit/chromium/DEPS b/WebKit/chromium/DEPS
index 07e385b..fc90187 100644
--- a/WebKit/chromium/DEPS
+++ b/WebKit/chromium/DEPS
@@ -143,6 +143,14 @@ deps_os = {
     'third_party/pthreads-win32':
       Var('chromium_deps_svn')+'/pthreads-win32@'+Var('pthreads-win32_rev'),
   },
+  'unix': {
+    # Linux, actually.
+    'third_party/harfbuzz':
+      Var('chromium_svn')+'/third_party/harfbuzz@'+Var('chromium_rev'),
+
+    'tools/xdisplaycheck':
+      Var('chromium_svn')+'/tools/xdisplaycheck@'+Var('chromium_rev'),
+  },
 }
 
 skip_child_includes = [
diff --git a/WebKit/chromium/WebKit.gyp b/WebKit/chromium/WebKit.gyp
index d7bd30d..7c0d913 100644
--- a/WebKit/chromium/WebKit.gyp
+++ b/WebKit/chromium/WebKit.gyp
@@ -40,6 +40,9 @@
                 # Webkit is being built outside of the full chromium project.
                 # e.g. via build-webkit --chromium
                 'chromium_src_dir': '.',
+                # FIXME: To enable shared_library in linux all code (including
+                # dependencies) must be complied with -fPIC flag. That is
+                # pending on changes in gyp.
                 'webkit_target_type': 'shared_library',
             },{
                 # WebKit is checked out in src/chromium/third_party/WebKit
@@ -51,6 +54,12 @@
             ['OS=="mac"', {
                 'chromium_code': 1,
             }],
+            # FIXME: To enable shared_library in linux all code (including
+            # dependencies) must be complied with -fPIC flag. That is
+            # pending on changes in gyp.
+            ['OS=="linux" or OS=="freebsd"', {
+              'webkit_target_type': 'static_library',
+            }],
         ],
     },
     'targets': [
diff --git a/WebKit/chromium/gyp_webkit b/WebKit/chromium/gyp_webkit
index 810af54..ef18239 100644
--- a/WebKit/chromium/gyp_webkit
+++ b/WebKit/chromium/gyp_webkit
@@ -32,6 +32,7 @@
 
 import glob
 import os
+import platform
 import shlex
 import sys
 
@@ -76,6 +77,10 @@ if __name__ == '__main__':
   # Add includes.
   args.extend(['-I' + i for i in additional_include_files(args)])
 
+  # On linux, we want gyp to output a makefile (default is scons).
+  if (platform.system() == 'Linux'):
+    args.extend(['-fmake'])
+
   # Other command args:
   args.extend([
                # gyp variable defines.
@@ -87,7 +92,7 @@ if __name__ == '__main__':
                '--depth=./',
 
                # gyp file to execute.
-               'webkit.gyp'])
+               'WebKit.gyp'])
 
   print 'Updating webkit projects from gyp files...'
   sys.stdout.flush()
diff --git a/WebKitTools/ChangeLog b/WebKitTools/ChangeLog
index 02cd276..55bfd5e 100644
--- a/WebKitTools/ChangeLog
+++ b/WebKitTools/ChangeLog
@@ -1,3 +1,12 @@
+2009-12-07  Yaar Schnitman  <yaar at chromium.org>
+
+        Reviewed by Darin Fisher.
+
+        fixes to build-webkit --chromium
+        https://bugs.webkit.org/show_bug.cgi?id=32179
+
+        * Scripts/webkitdirs.pm:
+
 2009-12-07  Eric Seidel  <eric at webkit.org>
 
         No review, just adding two recently approved committers.
diff --git a/WebKitTools/Scripts/webkitdirs.pm b/WebKitTools/Scripts/webkitdirs.pm
index 9e0c271..ae33708 100644
--- a/WebKitTools/Scripts/webkitdirs.pm
+++ b/WebKitTools/Scripts/webkitdirs.pm
@@ -1131,9 +1131,6 @@ sub buildVisualStudioProject
     }
 
     my $useenv = "/useenv";
-    if (isChromium()) {
-        $useenv = "";
-    }
 
     my @command = ($vcBuildPath, $useenv, $winProjectPath, $action, $config);
 
@@ -1405,6 +1402,46 @@ sub buildGtkProject($$@)
     return buildAutotoolsProject($clean, @buildArgs);
 }
 
+sub buildChromiumMakefile($$$)
+{
+    my ($dir, $target, $clean) = @_;
+    chdir $dir;
+    if ($clean) {
+        return system qw(rm -rf out);
+    }
+    my $config = configuration();
+    my @command = ("make", "-j4", "BUILDTYPE=$config", $target);
+    print join(" ", @command) . "\n";
+    return system @command;
+}
+
+sub buildChromiumVisualStudioProject($$)
+{
+    my ($projectPath, $clean) = @_;
+
+    my $config = configuration();
+    my $action = "/build";
+    $action = "/clean" if $clean;
+
+    # Find Visual Studio installation.
+    my $vsInstallDir;
+    my $programFilesPath = $ENV{'PROGRAMFILES'} || "C:\\Program Files";
+    if ($ENV{'VSINSTALLDIR'}) {
+        $vsInstallDir = $ENV{'VSINSTALLDIR'};
+    } else {
+        $vsInstallDir = "$programFilesPath/Microsoft Visual Studio 8";
+    }
+    $vsInstallDir = `cygpath "$vsInstallDir"` if isCygwin();
+    chomp $vsInstallDir;
+    $vcBuildPath = "$vsInstallDir/Common7/IDE/devenv.com";
+
+    # Create command line and execute it.
+    my @command = ($vcBuildPath, $projectPath, $action, $config);
+    print "Building results into: ", baseProductDir(), "\n";
+    print join(" ", @command), "\n";
+    return system @command;
+}
+
 sub buildChromium($@)
 {
     my ($clean, @options) = @_;
@@ -1412,19 +1449,15 @@ sub buildChromium($@)
     my $result = 1;
     if (isDarwin()) {
         # Mac build - builds the root xcode project.
-        $result = buildXCodeProject("WebKit/chromium/webkit",
-                                    $clean,
-                                    (@options));
-    } elsif (isCygwin()) {
+        $result = buildXCodeProject("WebKit/chromium/WebKit", $clean, (@options));
+    } elsif (isCygwin() || isWindows()) {
         # Windows build - builds the root visual studio solution.
-        $result = buildVisualStudioProject("WebKit/chromium/webkit.sln",
-                                           $clean);
+        $result = buildChromiumVisualStudioProject("WebKit/chromium/WebKit.sln", $clean);
     } elsif (isLinux()) {
-        # Linux build
-        # FIXME support linux.
-        print STDERR "Linux build is not supported. Yet.";
+        # Linux build - build using make.
+        $ result = buildChromiumMakefile("WebKit/chromium/", "WebKit", $clean);
     } else {
-        print STDERR "This platform is not supported by chromium.";
+        print STDERR "This platform is not supported by chromium.\n";
     }
     return $result;
 }

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list